# totui (Trade Ogre TUI)
A textual user interface (TUI) for the popular TradeOgre exchange

Has the ability to:

* Place Buy Orders
* Place Sell Orders
* List Order Books, Tickers, and Action History
* Withdraw to address for most coins
* Locate Deposit address
* & more!

## Dependencies
* Latest Chrome Browser (stable)


## Install (pip)
```shell
pip3 install totui
```

Configure `~/.totui/config.ini` (see below), then run
 
```shell
totui
```


## Install (Source)
From git source

```shell
git clone https://github.com/protomens/totui
cd totui
```

Build & Install

```shell
python3 setup.py install
```


## Configure

Totui now prompts you at the start for your API keys. 

Run:

`totui`


**Note:** *Your terminal size must be at least 178x62 otherwise you will get an error when trying to run this.* 

## Usage

Follow the menus and read the details. Read the on-screen instructions.

## Disclaimer

I am in no way responsible for your actions with this app. I am not liable for any erroneous buy/sell orders you may place using totui. Instead, be cautious and double check your orders before submitting them. This is good practice in general.

It is recommended that you verify all deposit and withdraw addresses before proceeding. Your errors or errors of the program are not my responsibility. It is advised to make sure you know what you are doing when it comes to finances. 

It is helpful to open a second tab in the Chrome browser to verify all addresses are correct and any transactions do go through. 

## License

GPL v3.0 

# Tipjar

If you feel so inclined as to leave a tip this app will cotinue in development and issues raised will be handled in a timely manner. Programming costs time and money and donating helps the cause of open source and app development. 

`XMR: 82iYCRic1nQHb8RkU1T8ZYgebv7mzuxRJXiZ8fQ1crNoMtPqZRy4Rr1aJ9ND7RMd5uHTR9z8GbugGMSokmEq5JYsEuKtwHP`

`DERO: dero1qyxctkgzee00jh3md4etc8kxkr8x4hh7cckezrhn7de39kj4xaf9xqqa6xeta`

`BTC: bc1q70qdes2xrxyc03fgwekmmt8j2rds0fmg3dehth`



